@@ -1,6 +1,6 @@
 /* 
 
-$Id: array.c,v 1.8 2005/05/03 07:50:34 dk Exp $ 
+$Id: array.c,v 1.10 2005/05/24 09:54:57 dk Exp $ 
 
 Implemenmtation of PHP::TieHash and PHP::TieArray methods
 
@@ -408,6 +408,33 @@ XS( PHP_TieArray_DELETE)
 #undef METHOD
 }
 
+/* 
+   Retrieve index of the last item in the array; return -1 if the array is empty .
+*/
+static long 
+array_last_index( HashTable * array)
+{
+	int klen;
+	char * key;
+	HashPosition hp;
+	unsigned long numkey;
+	long last = -1;
+
+	zend_hash_internal_pointer_reset_ex( array, &hp); 
+	while ( 1) {
+		switch( zend_hash_get_current_key_ex( array, 
+			&key, &klen, &numkey, 0, &hp)) 
+		{
+		case HASH_KEY_NON_EXISTANT:
+			return last;
+		case HASH_KEY_IS_LONG:
+			if ( last < (long) numkey) last = numkey;
+			break;
+		}
+		zend_hash_move_forward_ex( array, &hp);
+	}
+}
+
 XS( PHP_TieArray_FETCHSIZE)
 {
 	dXSARGS;
@@ -426,10 +453,107 @@ XS( PHP_TieArray_FETCHSIZE)
 	SP -= items;
 	PUTBACK;
 
-	XSRETURN_IV( zend_hash_num_elements( HASH_OF(array)));
+	XSRETURN_IV( 1 + array_last_index( HASH_OF(array)));
 #undef METHOD
 }
 
+XS( PHP_TieArray_PUSH)
+{
+	dXSARGS;
+	STRLEN na;
+	long i, pos;
+	zval * array, * zobj;
+	SV * val;
+
+#define METHOD "PHP::TieArray::PUSH"
+	if ( items < 1) 
+		croak("%s: expect at least 1 parameter", METHOD);
+
+	if (( array = SV2ZANY( ST(0))) == NULL)
+		croak("%s: (%s) is not a PHP array", METHOD, SvPV(ST(0), na));
+
+	pos = array_last_index( HASH_OF(array));
+	
+	DEBUG("push 0x%x %d items after %d", array, items - 1, pos);
+	
+	for ( i = 1; i < items; i++) {
+		DEBUG("push %s", SvPV( ST(i), na));
+
+		MAKE_STD_ZVAL( zobj);
+		zobj-> type = IS_NULL;
+		if ( !sv2zval( val = ST(i), zobj, -1)) {
+			zval_ptr_dtor( &zobj);
+			croak("%s: scalar (%s) type=%d cannot be converted", 
+				METHOD, SvPV( val, na), SvTYPE( val));
+		}
+
+		if ( zend_hash_index_update( 
+			HASH_OF(array), pos + i,
+			(void *)&zobj, sizeof(zval *), NULL
+			) == FAILURE) {
+			zval_ptr_dtor( &zobj);
+			croak("%s: failed", METHOD);
+		}
+	}
+
+	SP -= items;
+	PUTBACK;
+
+	XSRETURN_IV( pos + items);
+	
+#undef METHOD
+}
+
+XS( PHP_TieArray_POP)
+{
+	dXSARGS;
+	STRLEN na;
+	zval * array, **zobj;
+	SV * retsv;
+	long pos;
+
+#define METHOD "PHP::TieArray::POP"
+	if ( items != 1) 
+		croak("%s: expect 1 parameters", METHOD);
+
+	if (( array = SV2ZANY( ST(0))) == NULL)
+		croak("%s: (%s) is not a PHP array", METHOD, SvPV(ST(0), na));
+
+	pos = array_last_index( HASH_OF(array));
+
+	DEBUG("pop 0x%x at %d", array, pos);
+
+	SP -= items;
+	
+	if ( pos == -1) { /* empty array */
+		XPUSHs( &PL_sv_undef);
+		PUTBACK;
+		return;
+	}
+
+	if ( zend_hash_index_find( HASH_OF(array), pos, (void**) &zobj) == FAILURE) {
+		XPUSHs( &PL_sv_undef);
+		PUTBACK;
+		return;
+	}
+	
+	if ( !( retsv = zval2sv( *zobj))) {
+		warn("%s: value cannot be converted\n", METHOD);
+		retsv = &PL_sv_undef;
+	}
+
+	zend_hash_index_del( HASH_OF(array), pos);
+
+	if ( retsv != &PL_sv_undef) 
+		retsv = sv_2mortal( retsv);
+	XPUSHs( retsv);
+
+#undef METHOD
+	PUTBACK;
+
+	return;
+}
+
 void
 register_PHP_Array()
 {
@@ -449,6 +573,8 @@ register_PHP_Array()
 	newXS( "PHP::TieArray::STORE",	PHP_TieArray_STORE,	"PHP::TieArray");
 	newXS( "PHP::TieArray::DELETE",	PHP_TieArray_DELETE,	"PHP::TieArray");
 	newXS( "PHP::TieArray::CLEAR",	PHP_TieHash_CLEAR,	"PHP::TieArray");
+	newXS( "PHP::TieArray::PUSH",	PHP_TieArray_PUSH,	"PHP::TieArray");
+	newXS( "PHP::TieArray::POP",	PHP_TieArray_POP,	"PHP::TieArray");
 }
 
 #ifdef __cplusplus
